"""Package metadata """


__author__ = "Eric Busboom"
__copyright__ = "Copyright (c) 2019 Civic Knowledge"
__credits__ = []
__license__ = "Revised BSD"
__version__ = '1.1.2'
__maintainer__ = "Eric Busboom"
__email__ = 'eric@civicknowledge.com'
__status__ = "Development"